<?php 
/*
	Plugin Name: WooCommerce Price Parceled
	Plugin URI: https://woocommerce.com.br/instrucoes/tabela-de-parcelamento-para-woocommerce/
	Description: Displays the product price parceled example '3 x $100'
	Version: 2.0
	Author: John-Henrique 
	Author URI: https://johnhenrique.com.br
	Requires at least: 3.1
	Tested up to: 4.9.6
	Text domain: WC_Price_Parceled
*/
	

/**
 * Check if WooCommerce is active
 **/
if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
	

	function price_parceled_init(){
		
		
		class PriceParceled {
			
			
			
			/**
			 * Number of parcels
			 *
			 * @var integer
			 */
			protected $parcels = 2;
			
			
			/**
			 * Coefficient of parcels
			 *
			 * @var float
			 */
			protected $coefficient = 0;
			
			
			/**
			 * Minimum ammount value of parcels
			 *
			 * @var integer
			 */
			protected $minimum = 40;
			
			
			
			
			public function __construct(){
				
				
				// call save method
				add_action('woocommerce_update_options_payment_gateways', array( $this, 'process_admin_options'));
				
				// add parcel in product loop
				add_filter( 'woocommerce_after_shop_loop_item_title', array( $this, 'adiciona_parcela_unica' ) );
				
				// add table parcels in product details page
				add_filter( 'woocommerce_before_add_to_cart_form', array( $this, 'adiciona_tabela_parcelas' ) );
				//add_filter( 'woocommerce_after_add_to_cart_form', array( $this, 'adiciona_tabela_parcelas' ) );
				
				// show the admin options in catalog page of WooCommerce
				add_action( 'woocommerce_catalog_settings', array( $this, 'fields' ) ); // until 2.0
				add_action( 'woocommerce_product_settings', array( $this, 'fields' ) ); // 2.1+
				
				// add parcels on total
				add_action( 'woocommerce_cart_total', array( $this, 'adiciona_parcela_carrinho' ) );
				
				// add notices on shop cart
				add_action( 'woocommerce_before_cart_contents', array( $this, 'notificacoes' ) );
				
				
				add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'plugin_action_links' ) );
				
				// numero de parcelas permitidas
				$this->parcels = get_option( 'woocommerce_price_parceled_parcels' );
				if( $this->parcels == '' ){ $this->parcels = 2; }
				
				/*
				// depreciado
				// coeficiente/fator de juros a adicionar
				$this->coefficient = get_option( 'woocommerce_price_parceled_coefficient' );
				if( $this->coefficient == '' ){ $this->coefficient = 0; }
				*/
				
				// valor minimo que cada parcela pode ter
				$this->minimum = get_option( 'woocommerce_price_parceled_minimum' );
				if( $this->minimum == '' ){ $this->minimum = 40; }
				
			}
			
			/**
			 * Action links.
			 *
			 * @param array $links Action links.
			 *
			 * @return array
			 */
			public function plugin_action_links( $links ) {
				$plugin_links   = array();
				$plugin_links[] = '<a href="' . esc_url( admin_url( 'admin.php?page=wc-settings&tab=products' ) ) . '">' . __( 'Settings', 'woocommerce-pagseguro' ) . '</a>';

				return array_merge( $plugin_links, $links );
			}
			
			
			function adiciona_parcela_carrinho( $tes ){
				echo $tes . $this->helper_calcula_parcelas( WC()->cart->total);
			}
			
			
			
			/**
			 * Permite acessar o valor do coeficiente de juros de forma 
			 * mais simples 
			 *
			 * @param Integer $int_index index do campo 1 a 24
			 * @return Float
			 */
			protected function get_coefficient( $int_index = '1' ){
				return (float) str_replace( ',','.', get_option( 'woocommerce_price_parceled_coefficient'. $int_index ) );
			}
			
			
			
			/**
			 * Increment parcels
			 *
			 * @return Array
			 */
			protected function helper_parcelas(){
				$parcelas = array();
				for( $i=2; $i <= 24; $i++ ){
					$parcelas[ $i ] = $i;
				}
				
				return $parcelas;
			}
			
			
			
			
			/**
			 * Calcula se será necessário apresentar as 
			 * parcelas na loja toda
			 */
			protected function helper_parcela_minima( $product_id ){
				$product = wc_get_product( $product_id );
				//return $product->get_price();
				return $this->helper_calcula_parcelas( $product->get_price() );
			}
			
			
			/**
			 * Evoca o calculo de parcelas 
			 * na loja apenas nos
			 *
			 * @param String $content
			 * @return String
			 */
			public function adiciona_parcelas( $content ){
				global $post;
				
				echo $this->helper_parcela_minima( $post->ID );
			}
			
			
			
			
			/**
			 * Adiciona a tabela das parcelas 
			 * na página do produto
			 *
			 * @return String
			 */
			function adiciona_tabela_parcelas(){
				global $post;
				// Exibe somente se estivermos num produto
				if( is_product() ){ 
					echo $this->helper_parcela_minima( $post->ID );
				}
			}
			
			
			
			/**
			 * Adiciona uma única parcela 
			 * 	- Sempre exibirá a maior parcela permitida
			 * 	- Sempre entre o título do produto e botão 'comprar'
			 * 	- Apenas dentro do loop principal
			 *
			 */
			function adiciona_parcela_unica( $content ){
				$price = wc_get_product();
				echo $this->helper_calcula_parcelas( $price->get_price(), 'parcel' );
				return $content;
			}
			
			
			
			/**
			 * Evoca o calculo de parcelas
			 * no carrinho
			 *
			 * @param String $price
			 * @return String
			 */
			public function parcelas( $price ){
				
				$price_to_work = $price;
				
				
				$arrSearch = array(
					'<span class="amount">', 
					get_woocommerce_currency_symbol(), 
					'&nbsp;', 
					'</span>',
					'.', 
					','
				);
				
				$arrReplace = array(
					'', 
					'',
					'', 
					'',
					'',
					'.'
				);
				
				$price_to_work = str_replace( $arrSearch, $arrReplace, $price );
				
				return $price . $this->helper_calcula_parcelas( $price_to_work );
			}
			
			
			
			
			// calculate the parcels
			protected function helper_calcula_parcelas( $price, $mostrar_tabela_parcela = '' ){
				global $post;
				
				if( isset( $price ) && !empty( $this->parcels ) ){
					
					// produto sem preço?
					if( empty( $price ) ){
						$price = 0;
					}
					
					
					$parcels_price 		= round( ( (int)$price / (int)$this->parcels ), 2 );
					$mostrar_parcela 	= '';
					$mostrar_tabela 	= '';
					$juros				= '';
					
					
					$coeficiente = $this->get_coefficient( $this->parcels );
					if( !empty( $coeficiente ) ){
						$parcels_price = $price * $coeficiente;
						$juros = "";
					}else{
						//$parcels_price = round( $price / $this->parcels, 2 );
						$parcels_price = $parcels_price;
						$juros = "<span class='table_parcels_juros'>". __( "without interest", "WC_Price_Parceled" ) ."</span>";
					}
					
					if( $parcels_price >= $this->minimum ){
						
						
						/**
						 * Caso $mostrar_tabela_parcela esteja vazio 
						 * vamos ler o valor da opção woocommerce_price_parceled_table 
						 * a partir disso não teremos problemas com valores não 
						 * declarados ou regras sobrescritas.
						 */
						if( $mostrar_tabela_parcela == '' ){
							$mostrar_tabela_parcela = get_option( 'woocommerce_price_parceled_table' );
						}
						
						
						// mostrar tabela?
						if( ( $mostrar_tabela_parcela == 'table' ) or ( $mostrar_tabela_parcela == 'all' ) ){
							$mostrar_tabela = "<span>". $this->tabela_parcelas( $price ) ."</span>";
						}
						
						// mostrar parcela única?
						if( ( $mostrar_tabela_parcela == 'parcel' ) or ( $mostrar_tabela_parcela == 'all' ) ){
							$mostrar_parcela = "<br /><span class='price_parcels'>". __( 'or', 'WC_Price_Parceled' ) ." ". $this->parcels ." ". __( 'x', 'WC_Price_Parceled' ) ." ". wc_price( $parcels_price ) ."</span>";
						}
						
						return $mostrar_parcela . $mostrar_tabela;
					}
				}
			}
			
			
			
			/**
			 * Gera a tabela de parcelas
			 *
			 * @param String $price
			 * @return String
			 */
			public function tabela_parcelas( $price ){
				global $post;
				
				$table_html_head  = "<table class=\"table_parcels\" cellspacing=\"5\" cellpadding=\"5\" width=\"100%\">";
				$table_html_body = '';
				$table_html_footer = "</table>";
				$table_html_cols = 1;
				
				$linha_zebra = 'zebra';
				$juros = '';
				
				
				// verifica se é a página do produto
				if( is_product() ){
					/*
					$table_html_body .= '<tr class="zebra">';
					$table_html_body .= '<td><strong>". $i ."x</strong> ". wc_price( $parcels_price ) ."</td>';
					*/
					// gerando parcelas
					for( $i=2; $i <= $this->parcels; $i++ ){
						
						
						
						// Se a quantidade de colunas for 0 adicionamos
						if( $table_html_cols == 1 ){
							
							// zebrando tabela
							$linha_zebra = ( $linha_zebra == 'zebra' )? 'zebra':'nozebra';
							
							$table_html_body .= "<tr class=\"$linha_zebra\">";
						}
						
						
						//$table_html_body .= "<td><strong>". $i ."x</strong> ". wc_price( $parcels_price ) ."</td>";
						$coeficiente = $this->get_coefficient( $i );
						if( !empty( $coeficiente ) ){
							$preco_parcela = $price * $coeficiente;
							$juros = "";
						}else{
							$preco_parcela = round( $price / $i, 2 );
							$juros = "<span class='table_parcels_juros'>". __( "without interest", "WC_Price_Parceled" ) ."</span>";
						}
						$table_html_body .= "<td><strong>". $i ."x ". $juros ."</strong> ". wc_price( $preco_parcela ) ."</td>";
						
						
						// Se a quantidade de colunas for 2 adicionamos
						if( $table_html_cols == 2 ){
							$table_html_body .= "</tr>";
							
							$table_html_cols = 0;
							
							$linha_zebra = 'nozebra';
						}
						
						$table_html_cols++;
						$juros = "";
					}
					
					
					return "<p>". get_option( 'woocommerce_price_parceled_info_table' ) ."</p>". $table_html_head . $table_html_body . $table_html_footer;
				}
			}
			
			
			
			// display notice in shop cart
			public function notificacoes(){
				$str_info_table = str_replace( array( '%s', '{parcels}' ), $this->parcels, get_option( 'woocommerce_price_parceled_info_table' ) );
				echo "<div class=\"table_parceled_info woocommerce_info\"><p>". $str_info_table ."</p></div>";
			}
			
			
			
			public function fields( $arrFields ){
				
				$parcelas = array(
					array(	
						'name'		=> __( 'Parceling Options', 'WC_Price_Parceled' ), 
						'type'		=> 'title',
						'desc'		=> __('The following options affect how prices should be displayed on the frontend when parceling.', 'WC_Price_Parceled'), 
						'id'		=> 'parcels_options'
					),
					
					array(
						'name'		=> __( 'Parcels', 'WC_Price_Parceled' ), 
						'desc' 		=> __( 'This controls how many parcels the price will be divided.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_parcels',
						'std' 		=> 2,
						'type' 		=> 'select', 
						'options'	=> $this->helper_parcelas(), 
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
						
					),
					array(
						'name'		=> __( 'Minimum value', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the minimum amount that each parcel must have. If the parcel does no have the minimum value the price will not be divided.', 'WC_Price_Parceled' ),
						'id' 		=> 'woocommerce_price_parceled_minimum',
						'std' 		=> 40,
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					), 
					array(
						'name'		=> '1 '. __( 'parcel', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient1', 
						'class'		=> 'parcela', 
						'std' 		=> '0.00',
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '2 '. __( 'parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient2',
						'std' 		=> '0.00', 
						'class' 	=> 'parcela', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '3 '. __( 'parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient3',
						'std' 		=> '0.00', 
						'class' 	=> 'parcela', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '4 '. __( 'parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient4',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '5 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient5',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '6 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient6',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '7 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient7',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '8 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient8',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '9 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient9',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '10 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient10',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '11 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient11',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '12 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient12',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '13 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient13',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '14 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient14',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '15 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient15',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '16 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient16',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '17 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient17',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '18 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient18',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '19 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient19',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '20 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient20',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '21 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient21',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '22 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient22',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '23 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient23',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> '24 '. __('parcels', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This controls the interest factor that should be added to the plots. Leave 0 (zero) to no add interest.', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_coefficient24',
						'std' 		=> '0.00', 'class' => 'parcelas', 
						'type' 		=> 'text',
						'css' 		=> 'width:50px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> __( 'Display info', 'WC_Price_Parceled' ),
						'desc' 		=> __( 'This allow display a small message on table parcel and in shop cart. You can use CSS to customize the appearance of the message, use the class ".table_parceled_info"', 'WC_Price_Parceled' ), 
						'id' 		=> 'woocommerce_price_parceled_info_table',
						'std' 		=> sprintf( __( 'Parcel by credit card within %s parcels', 'WC_Price_Parceled' ), $this->parcels ),
						'type' 		=> 'textarea',
						'css' 		=> 'width:300px;',
						'desc_tip'	=> true
					),
					array(
						'name'		=> __( 'Display', 'WC_Price_Parceled' ),
						'desc'		=> __( 'This controls the display table parcels or display a parcel.', 'WC_Price_Parceled' ), 
						'id'		=> 'woocommerce_price_parceled_table',
						'std'		=> 'all', 
						'type'		=> 'select',
						'options' 	=> array( 
											'table'		=> __( 'Table parcels', 'WC_Price_Parceled' ), 
											'parcel'	=> __( 'The parcel', 'WC_Price_Parceled' ),
											'all'		=> __( 'Display all', 'WC_Price_Parceled' )
										),
						'desc_tip'	=> true
					),
					
					array( 
						'type' 		=> 'sectionend', 
						'id'		=> 'parcels_options' 
					),
				);
				
				return array_merge( $arrFields, $parcelas );
			}
			
			
			
			public function helper_js(){
				//$parent_file = get_admin_page_parent();
				
				// exibir o JS apenas se estiver na página catalogo do WooCommerce
				if( 
					/*$parent_file == 'woocommerce' && */
					isset( $_GET['page'] ) && 
					$_GET['page'] == 'wc-settings' && 
					isset( $_GET['tab'] ) && 
					$_GET['tab'] == 'products' /* && 
					isset( $_GET['section'] ) && // a opção display foi removida e realocada em Aparência/personalizar
					$_GET['section'] == 'display' */
					){
				?>
				<script language="javascript" type="text/javascript">
				jQuery( function(){
					console.log( "Carregando helper_js");
					/* tabela de parcelamento */
					jQuery( '.parcelas' ).each(function( index ){
						if( jQuery( this ).val() == "" ){
							jQuery( this ).closest('tr').slideUp();
						}
					});
					jQuery( '.parcela, .parcelas' ).click( function(){ 
						jQuery( '#'+ this.id ).closest( 'tr' ).next().slideDown();
					});
				})
				</script>
				<?php 
				}
				
			}
			
		}
		
		
	
		// textdomain
		load_plugin_textdomain('WC_Price_Parceled', false, basename( dirname( __FILE__ ) ) . '/languages' );
	
		
		$PriceParceled = new PriceParceled();
		add_filter('admin_head', array( $PriceParceled, 'helper_js' ) );
	}
	

	
	add_action('plugins_loaded', 'price_parceled_init', 0);
}



?>